@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11197 2018-08-06 09:55:55Z Lavender $
+# $Id: __init__.py 11211 2018-08-26 06:08:08Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-08-06 18:55:55 +0900 (週一, 06 八月 2018) $
-# $Revision: 11197 $
+# $Date: 2018-08-26 15:08:08 +0900 (週日, 26 八月 2018) $
+# $Revision: 11211 $
 
 from __future__ import print_function
 
@@ -837,6 +837,34 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     #=========================================================================
 
     #=========================================================================
+    
+    #=========================================================================
+    # HAYSTACK
+    BASE_DIR = settingsDict['BASE_DIR']
+    if settingsDict['DEBUG'] or sys.platform.startswith("win32"):
+        HAYSTACK_SETTINGS = {
+            'HAYSTACK_CONNECTIONS': {
+                'default': {
+                    'ENGINE': (
+                        'haystack.backends.whoosh_backend.WhooshEngine'),
+                    'PATH': os.path.join(BASE_DIR, 'whoosh_index'),
+                },
+            },
+        }
+    else:
+        HAYSTACK_SETTINGS = {
+            'HAYSTACK_CONNECTIONS': {
+                'default': {
+                    'ENGINE': 'xapian_backend.XapianEngine',
+                    'PATH': os.path.join(BASE_DIR, 'xapian_index'),
+                },
+            },
+        }
+    
+    if not 'HAYSTACK_CONNECTIONS' in settingsDict:
+        update(settingsDict, HAYSTACK_SETTINGS)
+
+    #=========================================================================
 
 
 # detect Server mode
