@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11206 2018-08-14 10:39:06Z Lavender $
+# $Id: views.py 11208 2018-08-25 14:31:26Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-08-14 19:39:06 +0900 (週二, 14 八月 2018) $
-# $Revision: 11206 $ 
+# $Date: 2018-08-25 23:31:26 +0900 (週六, 25 八月 2018) $
+# $Revision: 11208 $ 
 
 import json
 import logging
@@ -68,6 +68,10 @@ class SuccessResponseView(SuccessResponseView):
 
 # patch
 from oscar.apps.checkout import views
+from oscar.apps.dashboard.orders.views import OrderListView
+from oscar.core.compat import UnicodeCSVWriter
+from django.utils.datastructures import SortedDict
+from oscar.core.utils import format_datetime
 
 def get_context_data(self, **kwargs):
     kwargs = super(views.PaymentDetailsView, self).get_context_data(**kwargs)
@@ -105,6 +109,74 @@ def get_context_data(self, **kwargs):
 
 views.PaymentDetailsView.get_context_data = get_context_data
 
+def download_selected_orders(self, request, orders):
+    response = HttpResponse(content_type='text/csv')
+    response['Content-Disposition'] = 'attachment; filename=%s' \
+        % self.get_download_filename(request)
+    writer = UnicodeCSVWriter(open_file=response)
+
+    meta_data = (('number', _('Order number')),
+                    ('value', _('Order value')),
+                    ('date', _('Date of purchase')),
+                    ('num_items', _('Number of items')),
+                    ('status', _('Order status')),
+                    ('customer', _('Customer email address')),
+                    ('shipping_address_name', _('Deliver to name')),
+                    ('billing_address_name', _('Bill to name')),
+                    ('address', _('Address')),
+                    ('phone', _('Phone')),
+                    ('product', _('Product')),
+                    )
+    columns = SortedDict()
+    for k, v in meta_data:
+        columns[k] = v
+
+    writer.writerow(columns.values())
+    for order in orders:
+        row = columns.copy()
+        row['number'] = order.number
+        row['value'] = order.total_incl_tax
+        row['date'] = format_datetime(order.date_placed, 'DATETIME_FORMAT')
+        row['num_items'] = order.num_items
+        row['status'] = order.status
+        row['customer'] = order.email
+        row['address'] = ''
+        
+        phone = '%s' % order.shipping_address.phone_number
+        
+        # #FIXME:
+        # 目前電話去掉+886換0是給台灣用的
+        row['phone'] = phone.replace('+886', '0')
+        
+        row['product'] = ''
+        
+        for field in order.shipping_address.active_address_fields():
+            row['address'] += "%s \n" % field
+        
+        for i, line in enumerate(order.basket.lines.all(), 1):
+            product = line.product
+            attributes = product.attribute_summary
+            description = line.description
+            row['product'] += \
+                "%d : %s(%s) X %d \n" % (i, description, 
+                                            attributes, line.quantity)
+        
+        if order.shipping_address:
+            row['shipping_address_name'] = order.shipping_address.name
+        else:
+            row['shipping_address_name'] = ''
+        if order.billing_address:
+            row['billing_address_name'] = order.billing_address.name
+        else:
+            row['billing_address_name'] = ''
+        writer.writerow(row.values())
+        
+    response.content = '\xEF\xBB\xBF' + response.content
+    
+    return response
+
+OrderListView.download_selected_orders = download_selected_orders
+
 # /cathaybk/preview/
 # /cathaybk-credit/checkxml/
 @csrf_exempt
